# -*- coding: utf-8 -*-
# bg_image.rb $Revision: 0.0.4 $
# release date: 2012-03-26
# for tDiary 3.x with ruby 1.9.2+
# Copyright (c) 2011-2012 Teruo Kohashi <teruo@kohashi.org>
# Distributed under the GPL

# revision history
# 0.0.1 
# 0.0.2 2011-12-17
## 2011-12-22 add term range (FMMDDTMMDD), add default_image_file
# 0.0.3 2011-12-22
## 2012-02-26 changed ordinary plugin to embedded header type
## 2012-03-08 @conf to @conf
## 2012-03-26 remove trace code
# 0.0.4 2012-03-26
## 2012-04-22 published

def bg_image
	bgfile = @conf['bg_image.files']
	return nil if bgfile.nil? or bgfile.empty?
	defile = @conf['bg_image.default']
	bgpos  = @conf['bg_image.position'] || 'top center'
	bgrep  = @conf['bg_image.repeat'] || 'no-repeat'
	# specific image file
	return @index+bgfile, bgrep, bgpos if File.exists?( @index + bgfile )
	
	site_path, site_fname = File::split( bgfile )
	sys_path = File::dirname( $PROGRAM_NAME )
	path = "#{sys_path}/#{site_path}/"
	files = Dir.glob( path + site_fname )
	if files.nil? or files.empty?
		if defile
			return defile, bgrep, bgpos
		else
			return nil
		end
	end
	p = path.size
	files = files.collect{ |f| f[p..-1] }
	date = Time.now

	#YYYY-MM-DD
	key = date.strftime( '%Y-%m-%d' )
	ff = files.select{|f| /^#{key}.*/ =~ f }
	return site_path + '/' + ff.sample, bgrep, bgpos unless ff.empty?

	#MM-DD
	key = date.strftime( '%m-%d' )
	ff = files.select{|f| /^#{key}.*/ =~ f }
	return site_path + '/' + ff.sample, bgrep, bgpos unless ff.empty?

	#FMMDDTMMDD
	key = date.strftime( '%m%d' )
	ff = files.select { |f|
		fr, to = f.scan(/^F(\d{4})T(\d{4}).*/).flatten
		fr and to and ( (fr <= key and key <= to ) or (( fr >= to ) and ( fr <= key or key <= to )) )
	 }
	return site_path + '/' + ff.sample, bgrep, bgpos unless ff.empty?

	#weeks of year (00-53), start from sunday
	key = 'U' + date.strftime( '%U' )
	ff = files.select{|f| /^#{key}.*/ =~ f }
	return site_path + '/' + ff.sample, bgrep, bgpos unless ff.empty?

	#weeks of year (00-53), start from monday
	key = 'W' + date.strftime( '%W' )
	ff = files.select{|f| /^#{key}.*/ =~ f }
	return site_path + '/' + ff.sample, bgrep, bgpos unless ff.empty?

	#YYYY-MM
	key = date.strftime( '%Y-%m' )
	ff = files.select{|f| /^#{key}.*/ =~ f }
	return site_path + '/' + ff.sample, bgrep, bgpos unless ff.empty?

	#MM (01-12)
	key = date.strftime( '%m' )
	ff = files.select{|f| /^#{key}.*/ =~ f }
	return site_path + '/' + ff.sample, bgrep, bgpos unless ff.empty?

	# else
	if defile
		return defile, bgrep, bgpos
	else
		return site_path + '/' + files.sample, bgrep, bgpos
	end
end

def bg_image_result
	url, position, repeat = bg_image
	
	return '' if url.nil?
	result = ''
	result << <<-HTML
<style type="text/css">
<!--
body {
	background-image: url("#{h url}");
	background-position: #{position};
	background-repeat: #{repeat};
}
-->
</style>
	HTML

	result
end

if /^(saveconf|conf)$/ !~ @mode
	add_header_proc do
		bg_image_result
	end
end
